@@ -111,6 +111,7 @@ Available Events
 - :const:`~twitchAPI.types.ChatEvent.JOIN`: Triggered when someone other than the bot joins a channel. Note: this will not always trigger, depending on channel size
 - :const:`~twitchAPI.types.ChatEvent.JOINED`: Triggered when the bot joins a channel
 - :const:`~twitchAPI.types.ChatEvent.LEFT`: triggered when the bot left a channel
+- :const:`~twitchAPI.types.ChatEvent.MESSAGE_DELETE`: triggered when a message in a channel got deleted
 
 *******************
 Class Documentation
@@ -177,6 +178,26 @@ class EventData:
         """The :const:`twitchAPI.chat.Chat` instance"""
 
 
+class MessageDeletedEvent(EventData):
+    
+    def __init__(self, chat, parsed):
+        super(MessageDeletedEvent, self).__init__(chat)
+        self._room_name = parsed['command']['channel'][1:]
+        self.message: str = parsed['parameters']
+        """The content of the message that got deleted"""
+        self.user_name: str = parsed['tags'].get('login')
+        """Username of the message author"""
+        self.message_id: str = parsed['tags'].get('target-msg-id')
+        """ID of the message that got deleted"""
+        self.sent_timestamp: int = int(parsed['tags'].get('tmi-sent-ts'))
+        """The timestamp the deleted message was send"""
+
+    @property
+    def room(self) -> Optional[ChatRoom]:
+        """The room the message was deleted in"""
+        return self.chat.room_cache.get(self._room_name)
+
+
 class RoomStateChangeEvent(EventData):
     """Triggered when a room state changed"""
 
@@ -188,7 +209,7 @@ class RoomStateChangeEvent(EventData):
         """The new room state"""
 
     @property
-    def room(self):
+    def room(self) -> Optional[ChatRoom]:
         """Returns the Room from cache"""
         return self.chat.room_cache.get(self.new.name)
 
@@ -202,7 +223,7 @@ class JoinEvent(EventData):
         """The name of the user that joined"""
 
     @property
-    def room(self):
+    def room(self) -> Optional[ChatRoom]:
         """The room the user joined to"""
         return self.chat.room_cache.get(self._name)
 
@@ -267,7 +288,7 @@ class ChatMessage(EventData):
 
     async def reply(self, text: str):
         """Reply to this message"""
-        await self.chat._send_message(f'@reply-parent-msg-id={self.id} PRIVMSG #{self.room.name} :{text}')
+        await self.chat.send_raw_irc_message(f'@reply-parent-msg-id={self.id} PRIVMSG #{self.room.name} :{text}')
 
 
 class ChatCommand(ChatMessage):
@@ -293,6 +314,7 @@ class ChatSub:
 
     def __init__(self, chat, parsed):
         self.chat: 'Chat' = chat
+        """The :const:`twitchAPI.chat.Chat` instance"""
         self._parsed = parsed
         self.sub_type: str = parsed['tags'].get('msg-id')
         """The type of sub given"""
@@ -306,7 +328,7 @@ class ChatSub:
         """the system message that was generated for this sub"""
 
     @property
-    def room(self):
+    def room(self) -> Optional[ChatRoom]:
         """The room this sub was issued in"""
         return self.chat.room_cache.get(self._parsed['command']['channel'][1:])
 
@@ -321,8 +343,6 @@ class Chat:
         self.twitch: Twitch = twitch
         if not self.twitch.has_required_auth(AuthType.USER, [AuthScope.CHAT_READ]):
             raise ValueError('passed twitch instance is missing User Auth.')
-        # data = self.twitch.get_users()
-        # self.username: str = data['data'][0]['login'].lower()
         self.connection_url: str = connection_url if connection_url is not None else TWITCH_CHAT_URL
         self.ping_frequency: int = 120
         self.ping_jitter: int = 4
@@ -333,11 +353,9 @@ class Chat:
         self.__socket_thread: threading.Thread = None
         self.__running: bool = False
         self.__socket_loop = None
-        self.__topics: dict = {}
         self.__startup_complete: bool = False
         self.__tasks = None
         self.__waiting_for_pong: bool = False
-        self.__nonce_waiting_confirm: dict = {}
         self._event_handler = {}
         self._command_handler = {}
         self.room_cache: Dict[str, ChatRoom] = {}
@@ -486,7 +504,8 @@ class Chat:
     def _parse_irc_command(self, raw_command_component: str):
         command_parts = raw_command_component.split(' ')
 
-        if command_parts[0] in ('JOIN', 'PART', 'NOTICE', 'CLEARCHAT', 'HOSTTARGET', 'PRIVMSG', 'USERSTATE', 'ROOMSTATE', '001', 'USERNOTICE'):
+        if command_parts[0] in ('JOIN', 'PART', 'NOTICE', 'CLEARCHAT', 'HOSTTARGET', 'PRIVMSG',
+                                'USERSTATE', 'ROOMSTATE', '001', 'USERNOTICE', 'CLEARMSG'):
             parsed_command = {
                 'command': command_parts[0],
                 'channel': command_parts[1]
@@ -562,6 +581,12 @@ class Chat:
         await self._session.close()
         # wait for ssl to close as per aiohttp docs...
         await asyncio.sleep(0.25)
+        # clean up bot state
+        self.__connection = None
+        self._session = None
+        self.room_cache = {}
+        self._room_join_locks = []
+        self._room_leave_locks = []
         self._closing = True
 
     async def __connect(self, is_startup=False):
@@ -631,6 +656,7 @@ class Chat:
                             'ROOMSTATE': self._handle_room_state,
                             'JOIN': self._handle_join,
                             'USERNOTICE': self._handle_user_notice,
+                            'CLEARMSG': self._handle_clear_msg,
                             'CAP': self._handle_cap_reply,
                             'PART': self._handle_part
                         }
@@ -648,6 +674,12 @@ class Chat:
             # print('we are closing down!')
             return
 
+    async def _handle_clear_msg(self, parsed: dict):
+        ev = MessageDeletedEvent(self, parsed)
+        for handler in self._event_handler.get(ChatEvent.MESSAGE_DELETE, []):
+            t = asyncio.ensure_future(handler(ev))
+            t.add_done_callback(self._task_callback)
+
     async def _handle_cap_reply(self, parsed: dict):
         self.logger.debug(f'got CAP reply, granted caps: {parsed["parameters"]}')
         caps = parsed['parameters'].split()
@@ -700,7 +732,7 @@ class Chat:
             is_followers_only=parsed['tags'].get('followers-only') != '-1',
             is_unique_only=parsed['tags'].get('r9k') == '1',
             follower_only_delay=int(parsed['tags'].get('followers-only', '-1')),
-            room_id=parsed['tags'].get('room_id'),
+            room_id=parsed['tags'].get('room-id'),
             slow=int(parsed['tags'].get('slow', '0')))
         prev = self.room_cache.get(state.name)
         # create copy
@@ -787,12 +819,30 @@ class Chat:
         while any([r in self._room_join_locks for r in target]):
             await asyncio.sleep(0.01)
 
+    async def send_raw_irc_message(self, message: str):
+        """Send a raw IRC message
+
+        :param message: the message to send
+        """
+        if message is None or len(message) == 0:
+            raise ValueError('message must be a non empty string')
+        await self._send_message(message)
+
     async def send_message(self, room: Union[str, ChatRoom], text: str):
+        """Send a message to the given channel
+
+        Please note that you first need to join a channel before you can send a message to it.
+
+        :param room: The chat room you want to send the message to.
+            This can either be a instance of :const:`~twitchAPI.types.ChatRoom` or a string with the room name (either with leading # or without)
+        :param text: The text you want to send
+        :raises ValueError: if message is empty or room is not given
+        """
         if isinstance(room, ChatRoom):
             room = room.name
-        if len(room) == 0:
+        if room is None or len(room) == 0:
             raise ValueError('please specify a room to post to')
-        if len(text) == 0:
+        if text is None or len(text) == 0:
             raise ValueError('you can\'t send a empty message')
         if room[0] != '#':
             room = f'#{room}'
